@@ -4,7 +4,7 @@ use 5.008;
 use strict;
 use warnings;
 
-use parent qw(Eixo::Base::Clase);
+use Eixo::Base::Clase;
 use JSON;
 use Net::HTTP;
 use Eixo::Rest::Client;
@@ -14,7 +14,7 @@ use Eixo::Rest::Client;
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
 
-our $VERSION = '1.208';
+our $VERSION = '1.210';
 
 our $IDENTITY_FUNC = sub {
 
